summaryrefslogtreecommitdiff
path: root/include/modules.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/modules.h')
-rw-r--r--include/modules.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/include/modules.h b/include/modules.h
index ff52cd600..edfe31007 100644
--- a/include/modules.h
+++ b/include/modules.h
@@ -35,7 +35,8 @@ enum ModuleFlags {
VF_VENDOR = 2, // module is a vendor module (came in the original tarball, not 3rd party)
VF_SERVICEPROVIDER = 4, // module provides a service to other modules (can be a dependency)
VF_COMMON = 8, // module needs to be common on all servers in a network to link
- VF_OPTCOMMON = 16 // module should be common on all servers for unsurprising behavior
+ VF_OPTCOMMON = 16, // module should be common on all servers for unsurprising behavior
+ VF_CORE = 32 // module is a core command, can be assumed loaded on all servers
};
/** Used with SendToMode()